@@ -1565,3 +1565,277 @@ class Image(FunctionNode):
             raise AIEError(AIEErrorCode.ARGS_ERROR, "参数kernel不能为空")
 
         return FunctionHelper.apply("Image.convolve", "aie.Image", invoke_args)
+
+    def toByte(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.toByte", "aie.Image", invoke_args)
+
+    def toInt16(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.toInt16", "aie.Image", invoke_args)
+
+    def toUint16(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.toUint16", "aie.Image", invoke_args)
+
+    def toInt32(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.toInt32", "aie.Image", invoke_args)
+
+    def toUint32(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.toUint32", "aie.Image", invoke_args)
+
+    def toFloat(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.toFloat", "aie.Image", invoke_args)
+
+    def toDouble(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.toDouble", "aie.Image", invoke_args)
+
+    def selfMask(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.selfMask", "aie.Image", invoke_args)
+
+    def polynomial(self, coeffs: list) -> aie.Image:
+
+        if coeffs is not None and not isinstance(coeffs, list):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"coeffs 只支持list类型参数, 传入类型为{type(coeffs)}"
+            )
+
+        invoke_args = {
+            "input": self,
+            "coeffs": coeffs,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "coeffs" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数coeffs不能为空")
+
+        return FunctionHelper.apply("Image.polynomial", "aie.Image", invoke_args)
+
+    def gamma(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.gamma", "aie.Image", invoke_args)
+
+    def digamma(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.digamma", "aie.Image", invoke_args)
+
+    def remap(
+        self,
+        fromValue: list,
+        toValue: list,
+        defaultValue: [int, float] = None,
+        bandName: str = None,
+    ) -> aie.Image:
+
+        if fromValue is not None and not isinstance(fromValue, list):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"fromValue 只支持list类型参数, 传入类型为{type(fromValue)}",
+            )
+
+        if toValue is not None and not isinstance(toValue, list):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"toValue 只支持list类型参数, 传入类型为{type(toValue)}"
+            )
+
+        if defaultValue is not None and not isinstance(defaultValue, (int, float)):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"defaultValue 只支持(int,float)类型参数, 传入类型为{type(defaultValue)}",
+            )
+
+        if bandName is not None and not isinstance(bandName, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"bandName 只支持str类型参数, 传入类型为{type(bandName)}"
+            )
+
+        invoke_args = {
+            "input": self,
+            "fromValue": fromValue,
+            "toValue": toValue,
+            "defaultValue": defaultValue,
+            "bandName": bandName,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "fromValue" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数fromValue不能为空")
+
+        if "toValue" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数toValue不能为空")
+
+        return FunctionHelper.apply("Image.remap", "aie.Image", invoke_args)
+
+    def erf(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.erf", "aie.Image", invoke_args)
+
+    def erfc(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.erfc", "aie.Image", invoke_args)
+
+    def erfInv(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.erfInv", "aie.Image", invoke_args)
+
+    def erfcInv(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.erfcInv", "aie.Image", invoke_args)
+
+    def pixelArea(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.pixelArea", "aie.Image", invoke_args)
+
+    def derivative(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.derivative", "aie.Image", invoke_args)
+
+    def entropy(self, kernel: aie.Kernel) -> aie.Image:
+
+        if kernel is not None and not isinstance(kernel, aie.Kernel):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"kernel 只支持aie.Kernel类型参数, 传入类型为{type(kernel)}",
+            )
+
+        invoke_args = {
+            "input": self,
+            "kernel": kernel,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "kernel" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数kernel不能为空")
+
+        return FunctionHelper.apply("Image.entropy", "aie.Image", invoke_args)
+
+    def distance(self, kernel: aie.Kernel, skipMasked: bool = True) -> aie.Image:
+
+        if kernel is not None and not isinstance(kernel, aie.Kernel):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"kernel 只支持aie.Kernel类型参数, 传入类型为{type(kernel)}",
+            )
+
+        if skipMasked is not None and not isinstance(skipMasked, bool):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"skipMasked 只支持bool类型参数, 传入类型为{type(skipMasked)}",
+            )
+
+        invoke_args = {
+            "input": self,
+            "kernel": kernel,
+            "skipMasked": skipMasked,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "kernel" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数kernel不能为空")
+
+        return FunctionHelper.apply("Image.distance", "aie.Image", invoke_args)
