@@ -40,9 +40,14 @@ class Maps(object):
             "visParams": vis_params
         }
 
+        options_serialize = ""
+        try: 
+            options_serialize = json.dumps(options, ensure_ascii=False, allow_nan=False)
+        except Exception as e:
+            raise aie.error.AIEError(aie.error.AIEErrorCode.ARGS_ERROR, "请检查visParams参数", str(e))
         data = {"requestId": request_id,
                 "expr": expr,
-                "options": json.dumps(options)}
+                "options": options_serialize}
 
         url = Endpoints.SDK_GATEWAY + SdkGatewayResource.Maps.GET_MAP_ID
         return Client.post(url, data)
